==> tasks-v1.8.8.zip: tasks/messages/es/base.php <==
<?php

return [
    '1 Day before' => '1 día antes',
    '1 Month before' => '1 mes antes',
    '1 Week before' => '1 semana antes',
    '2 Days before' => '2 días antes',
    '2 Weeks before' => '2 semanas antes',
    '3 Weeks before' => '3 semanas antes',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Sólo los usuarios asignados</strong> están permitidos para trabajar esta tarea.',
    '<strong>Confirm</strong> task deletion' => '<strong>Confirmar</strong> borrado de tarea',
    '<strong>Create</strong> task list' => '<strong>Crear</strong> listas de tareas',
    '<strong>Edit</strong> task' => '<strong>Editar</strong> tarea',
    '<strong>Edit</strong> task list' => '<strong>Editar</strong> lista de tareas',
    '<strong>New</strong> Task' => '<strong>Nueva</strong> tarea',
    '<strong>Task</strong> Overview' => 'Vista general de las <strong>Tareas</strong>',
    '<strong>Tasks</strong>' => '<strong>Tareas</strong>',
    '<strong>Tasks</strong> module configuration' => 'Configuración del módulo <strong>Tareas</strong>',
    '<strong>Your</strong> tasks' => '<strong>Tus</strong> tareas',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Un widget es un elemento que se añade a la barra lateral de un flujo. En este caso proporciona a los usuarios una descripción corta de sus tareas.',
    'Accept Task' => 'Aceptar tarea',
    'Add Deadline to space calendar' => 'Agregar fecha de límite al calendario del espacio',
    'Add checkpoint...' => 'Agregar checkpoint...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Añadir puntos de control a las tareas para marcar los pasos necesarios para completarla.',
    'Add entry to main navigation' => 'Añadir una entrada en la navegación principal',
    'Add reminder' => 'Agregar recordatorio',
    'Add responsible users' => 'Agregar usuarios responsables',
    'Add schedule to the space calendar' => 'Agendar en el calendario del espacio',
    'Add task' => 'Agregar tarea',
    'Add to space calendar' => 'Agregar al calendario del espacio',
    'Additional options' => 'Opciones adicionales',
    'All Day' => 'Todo el día',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permitir al usuario crear nuevas tareas, el usuario podrá sólo editar y eliminar sus propias tareas.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permite al usuario crear, eliminar y editar tareas y listas, como también ordenar tareas y listas.',
    'Allows the user to process unassigned tasks' => 'Permitir a los usuarios trabajar en tareas con usuarios sin asignar',
    'Already requested' => 'Ya solicitado',
    'Any user with a "Process unassigned tasks" permission can work on this task' => 'Cualquier usuario el cual con un permiso de "procesar tareas sin asignar" puede trabajar en esta tarea',
    'Anyone can work on this task!' => 'Cualquiera puede trabajar en esta tarea!',
    'Assign myself' => 'Asignármela a mí mismo',
    'Assign users' => 'Asignar usuarios',
    'Assigned' => 'Asignado',
    'Assigned users' => 'Usuarios asignados',
    'Assignment' => 'Asignación',
    'Assignments:' => 'Asignados:',
    'At least 1 Hour before' => 'Al menos 1 hora antes',
    'At least 2 Hours before' => 'Al menos 2 horas antes',
    'Attachments' => 'Archivos vinculados',
    'Begin Task' => 'Comenzar tarea',
    'Checklist Items' => 'Ítems del Checklist',
    'Checklist:' => 'Checklist:',
    'Checkpoints' => 'Puntos de control',
    'Choose if you want the module to appear in the main navigation.' => 'Selecciona si quieres que el módulo aparezca en la navegación principal.',
    'Close' => 'Cerrar',
    'Color' => 'Color',
    'Completed' => 'Completado',
    'Completed lists' => 'Listas completadas',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configura el módulo Tareas para que se ajuste a tus requisitos y necesidades específicas. Puedes establecer configuraciones individuales y, por ejemplo, decidir si se muestra o no un widget.',
    'Continue Review' => 'Continuar revisión',
    'Create tasks' => 'Crear tareas',
    'Created by me' => 'Creada por mí',
    'Date' => 'Fecha',
    'Deadline at' => 'Fecha límite:',
    'Deadline: ' => 'Fecha límite:',
    'Delete' => 'Borrar',
    'Delete list' => 'Eliminar lista',
    'Description' => 'Descripción',
    'Do not remind' => 'No recordar',
    'Do you really want to delete this task?' => '¿Realmente deseas borrar esta tarea?',
    'Don\'t add to calendar' => 'No agendar en el calendario',
    'Drag entry' => 'Arrastrar entrada',
    'Edit' => 'Editar',
    'Edit item (empty field will be removed)...' => 'Editar ítem (los campos vacíos serán removidos)...',
    'Edit list' => 'Editar lista',
    'End' => 'Fin',
    'End Date' => 'Fecha de fin',
    'End Time' => 'Hora Final',
    'End date' => 'Fecha de término',
    'End time must be after start time!' => '¡La fecha de fin tiene que ser después de la fecha de inicio!',
    'Extend deadline request' => 'Extender solicitud de extensión de fecha límite',
    'Filter' => 'Filtro',
    'Filter by status' => 'Filtrar por estado',
    'Filter by title' => 'Filtrar por título',
    'Filter tasks' => 'Filtrar tareas',
    'Finish Task' => 'Finalizar tarea',
    'General' => 'General',
    'General Settings' => 'Ajustes generales',
    'Hide this list once all tasks are completed' => 'Esconder esta lista una vez que todas las tareas estén completadas.',
    'I\'m assigned' => 'Estoy asignado',
    'I\'m responsible' => 'Soy responsable',
    'If empty any user can complete the task.' => 'Si está vacío, cualquier usuario puede completar la tarea',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Si no hay usuarios asignados seleccionados, cada miembro del espacio con los permisos para trabajar en tareas sin asignar, podrán procesar dichas tareas.',
    'In Progress' => 'En progreso',
    'In Review' => 'En revisión',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'En caso de estar activa la opción de revisión, un <strong>usuario responsable</strong> podrá revisar, rechazar o incluso confirmar esta tarea antes de que sea completada.',
    'Invalid task list selection.' => 'Selección de lista de tareas inválida.',
    'Let Task Review' => 'Permitir revisión de tareas',
    'Main Navigation' => 'Navegación principal',
    'Manage tasks' => 'Organizar tareas',
    'Maximum number of entries in widget' => 'Número máximo de entradas en el widget',
    'Module Widget' => 'Widget de módulo',
    'New list or search' => 'Nueva lista o búsqueda',
    'No Scheduling set for this Task' => 'No se ha agendado esta tarea',
    'No pending tasks found' => 'No se han encontrado tareas pendientes',
    'No results found for the given filter.' => 'No hay resultados encontrados para el filtro dado.',
    'Open Task' => 'Abrir tarea',
    'Other Tasks' => 'Otras tareas',
    'Overdue' => 'Atrasado',
    'Overview' => 'Resúmen',
    'Parent Task' => 'Tarea principal',
    'Pending' => 'Pendiente',
    'Pending Review' => 'Pendiente de Revisar',
    'Process unassigned tasks' => 'Procesar tareas sin asignar',
    'Ready For Review' => 'Listo para revisión',
    'Receive Notifications for Task Reminder.' => 'Recibe notificaciones para recordatorios de tareas.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Recibe notificaciones para tareas (Fechas de entrega, actualizaciones..)',
    'Reject Task' => 'Rechazar tarea',
    'Remind Mode' => 'Modo de recordatorio',
    'Reminder' => 'Recordatorio',
    'Reminder sent' => 'Recordatorio enviado',
    'Reminders' => 'Recordatorios',
    'Request extension' => 'Solicitar extensión de plazo',
    'Request sent' => 'Solicitud enviada',
    'Reset Task' => 'Reiniciar tarea',
    'Responsible' => 'Responsable',
    'Responsible users' => 'Usuarios responsables',
    'Review by responsible user required' => 'Se requiere la revisión por los usuarios responsables',
    'Scheduling' => 'Agendado',
    'Show widget in Spaces' => 'Mostrar el widget en Espacios',
    'Show widget on Dashboard' => 'Mostrar el widget en el tablero',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostrar {count} más completada {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Orden de clasificación',
    'Sort order' => 'Ordenado por',
    'Spaces' => 'Espacios',
    'Start' => 'Empezar',
    'Start Date' => 'Fecha de inicio',
    'Start Time' => 'Hora de Inicio',
    'Start date' => 'Fecha de inicio',
    'Starting at' => 'Comienza:',
    'Status' => 'Estado',
    'Task' => 'Tarea',
    'Task List' => 'Lista de tareas',
    'Task Users have been notified' => 'Usuarios de tareas han sido notificado',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Tarea {task} en espacio {spaceName} termina: {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Tarea {task} en espacio {spaceName} comienza: {dateTime}.',
    'Tasks' => 'Tareas',
    'Tasks: Reminder' => 'Tareas: Recordatorio',
    'This task can only be processed by assigned and responsible users.' => 'Esta tarea puede sólo ser procesada por <strong>usuarios asignados y responsables.</strong>',
    'This task requires to be reviewed by a responsible' => 'Esta tarea requiere ser revisada por un responsable',
    'Time Zone' => 'Zona horaria',
    'Title' => 'Título',
    'Title and Color' => 'Título y Color',
    'Title of your task list' => 'Título de tu lista de tareas',
    'Today' => 'Hoy',
    'Unsorted' => 'Sin ordenar',
    'View Online' => 'Ver en línea',
    'You are assigned!' => 'Has sido asignado!',
    'You are responsible!' => 'Tú eres responsable de esta tarea!',
    'You have insufficient permissions to perform that operation!' => '¡No tienes suficientes permisos para hacer esa operación!',
    'Your Reminder for task {task}' => 'Tu recordatorio para la tarea {task}',
    'ending Review' => 'finalizando Revisión',
    'view all' => 'ver todo',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{Queda # día} other{Quedan # días}}',
    '{displayName} is assigned to this task' => '{displayName} ha sido asignado para esta tarea',
    '{displayName} is responsible for this task' => '{displayName} es responsable de esta tarea',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} te ha asignado como <strong>persona responsable</strong> a cargo de la tarea {task} desde el espacio {spaceName}',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} te ha asignado la tarea {task} en el espacio {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} completó la tarea: {task} en el espacio {spaceName}.',
    '{userName} completed task {task}.' => '{userName} completó la tarea {task}.',
    '{userName} finished task {task}.' => '{userName} completó la tarea {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} ha cambiado la fecha límite de la tarea {task} en el espacio {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} ha re-abierto la tarea {task} en el espacio {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} ha calificado la tarea {task} en el espacio {spaceName} como incompleta.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} marcó la tarea {task} en el espacio {spaceName} como completada.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} ha solicitado una extensión de la fecha de entrega para la tarea {task} en el espacio {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} te ha solicitado revisar la tarea: {task} en el espacio {spaceName}.',
    '{userName} reset task {task}.' => '{userName} restauró la tarea {task}.',
    '{userName} reviewed task {task}.' => '{userName} revisó la tarea {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} ha empezado a trabajar en la tarea: {task} en el espacio {spaceName}.',
    '{userName} works on task {task}.' => '{userName} está trabajando en la tarea {task}.',
    'Task content ID' => '',
];

==> tasks-v1.9.2.zip: tasks/messages/es/base.php <==
<?php

return [
    '1 Day before' => '1 día antes',
    '1 Month before' => '1 mes antes',
    '1 Week before' => '1 semana antes',
    '2 Days before' => '2 días antes',
    '2 Weeks before' => '2 semanas antes',
    '3 Weeks before' => '3 semanas antes',
    '<strong>Assigned users</strong> are allowed to process this task.' => '<strong>Sólo los usuarios asignados</strong> están permitidos para trabajar esta tarea.',
    '<strong>Confirm</strong> task deletion' => '<strong>Confirmar</strong> borrado de tarea',
    '<strong>Create</strong> task list' => '<strong>Crear</strong> listas de tareas',
    '<strong>Edit</strong> task' => '<strong>Editar</strong> tarea',
    '<strong>Edit</strong> task list' => '<strong>Editar</strong> lista de tareas',
    '<strong>New</strong> Task' => '<strong>Nueva</strong> tarea',
    '<strong>Task</strong> Overview' => 'Vista general de las <strong>Tareas</strong>',
    '<strong>Tasks</strong>' => '<strong>Tareas</strong>',
    '<strong>Tasks</strong> module configuration' => 'Configuración del módulo <strong>Tareas</strong>',
    '<strong>Your</strong> tasks' => '<strong>Tus</strong> tareas',
    'A widget is an element added to to the sidebar of a stream. In this case it provides users with a short overview of their tasks.' => 'Un widget es un elemento que se añade a la barra lateral de un flujo. En este caso proporciona a los usuarios una descripción corta de sus tareas.',
    'Accept Task' => 'Aceptar tarea',
    'Add Deadline to space calendar' => 'Agregar fecha de límite al calendario del espacio',
    'Add checkpoint...' => 'Agregar checkpoint...',
    'Add checkpoints to the task to highlight the individual steps required to complete it.' => 'Añadir puntos de control a las tareas para marcar los pasos necesarios para completarla.',
    'Add entry to main navigation' => 'Añadir una entrada en la navegación principal',
    'Add reminder' => 'Agregar recordatorio',
    'Add responsible users' => 'Agregar usuarios responsables',
    'Add schedule to the space calendar' => 'Agendar en el calendario del espacio',
    'Add task' => 'Agregar tarea',
    'Add to space calendar' => 'Agregar al calendario del espacio',
    'Additional options' => 'Opciones adicionales',
    'All Day' => 'Todo el día',
    'Allows the user to create new tasks, the user will only be able to edit and delete own tasks' => 'Permitir al usuario crear nuevas tareas, el usuario podrá sólo editar y eliminar sus propias tareas.',
    'Allows the user to create, delete and edit tasks and lists and also sort tasks and lists' => 'Permite al usuario crear, eliminar y editar tareas y listas, como también ordenar tareas y listas.',
    'Allows the user to process unassigned tasks' => 'Permitir a los usuarios trabajar en tareas con usuarios sin asignar',
    'Already requested' => 'Ya solicitado',
    'Assign myself' => 'Asignármela a mí mismo',
    'Assign users' => 'Asignar usuarios',
    'Assigned users' => 'Usuarios asignados',
    'Assignment' => 'Asignación',
    'At least 1 Hour before' => 'Al menos 1 hora antes',
    'At least 2 Hours before' => 'Al menos 2 horas antes',
    'Attachments' => 'Archivos vinculados',
    'Begin Task' => 'Comenzar tarea',
    'Checklist Items' => 'Ítems del Checklist',
    'Checklist:' => 'Checklist:',
    'Checkpoints' => 'Puntos de control',
    'Choose if you want the module to appear in the main navigation.' => 'Selecciona si quieres que el módulo aparezca en la navegación principal.',
    'Close' => 'Cerrar',
    'Color' => 'Color',
    'Completed' => 'Completado',
    'Completed lists' => 'Listas completadas',
    'Configure the Tasks module to meet your specific requirements and needs. You can define individual settings and for instance decide whether a widget is displayed.' => 'Configura el módulo Tareas para que se ajuste a tus requisitos y necesidades específicas. Puedes establecer configuraciones individuales y, por ejemplo, decidir si se muestra o no un widget.',
    'Continue Review' => 'Continuar revisión',
    'Create tasks' => 'Crear tareas',
    'Created by me' => 'Creada por mí',
    'Date' => 'Fecha',
    'Deadline: ' => 'Fecha límite:',
    'Delete' => 'Borrar',
    'Delete list' => 'Eliminar lista',
    'Description' => 'Descripción',
    'Do not remind' => 'No recordar',
    'Do you really want to delete this task?' => '¿Realmente deseas borrar esta tarea?',
    'Don\'t add to calendar' => 'No agendar en el calendario',
    'Edit' => 'Editar',
    'Edit item (empty field will be removed)...' => 'Editar ítem (los campos vacíos serán removidos)...',
    'Edit list' => 'Editar lista',
    'End' => 'Fin',
    'End Date' => 'Fecha de fin',
    'End Time' => 'Hora Final',
    'End date' => 'Fecha de término',
    'End time must be after start time!' => '¡La fecha de fin tiene que ser después de la fecha de inicio!',
    'Extend deadline request' => 'Extender solicitud de extensión de fecha límite',
    'Filter' => 'Filtro',
    'Filter by status' => 'Filtrar por estado',
    'Filter by title' => 'Filtrar por título',
    'Filter tasks' => 'Filtrar tareas',
    'Finish Task' => 'Finalizar tarea',
    'General' => 'General',
    'General Settings' => 'Ajustes generales',
    'Hide this list once all tasks are completed' => 'Esconder esta lista una vez que todas las tareas estén completadas.',
    'I\'m assigned' => 'Estoy asignado',
    'I\'m responsible' => 'Soy responsable',
    'If empty any user can complete the task.' => 'Si está vacío, cualquier usuario puede completar la tarea',
    'If no assigned user is selected, every space member with the permission to process unassigned tasks can process the task.' => 'Si no hay usuarios asignados seleccionados, cada miembro del espacio con los permisos para trabajar en tareas sin asignar, podrán procesar dichas tareas.',
    'In Progress' => 'En progreso',
    'In Review' => 'En revisión',
    'In case the review option is active, a <strong>responsible user</strong> will have to review and either reject or confirm this task before completion.' => 'En caso de estar activa la opción de revisión, un <strong>usuario responsable</strong> podrá revisar, rechazar o incluso confirmar esta tarea antes de que sea completada.',
    'Invalid task list selection.' => 'Selección de lista de tareas inválida.',
    'Let Task Review' => 'Permitir revisión de tareas',
    'Main Navigation' => 'Navegación principal',
    'Manage tasks' => 'Organizar tareas',
    'Maximum number of entries in widget' => 'Número máximo de entradas en el widget',
    'Module Widget' => 'Widget de módulo',
    'New list or search' => 'Nueva lista o búsqueda',
    'No Scheduling set for this Task' => 'No se ha agendado esta tarea',
    'No pending tasks found' => 'No se han encontrado tareas pendientes',
    'No results found for the given filter.' => 'No hay resultados encontrados para el filtro dado.',
    'Open Task' => 'Abrir tarea',
    'Other Tasks' => 'Otras tareas',
    'Overdue' => 'Atrasado',
    'Overview' => 'Resúmen',
    'Parent Task' => 'Tarea principal',
    'Pending' => 'Pendiente',
    'Pending Review' => 'Pendiente de Revisar',
    'Process unassigned tasks' => 'Procesar tareas sin asignar',
    'Ready For Review' => 'Listo para revisión',
    'Receive Notifications for Task Reminder.' => 'Recibe notificaciones para recordatorios de tareas.',
    'Receive Notifications for Tasks (Deadline Updates, Status changes ...).' => 'Recibe notificaciones para tareas (Fechas de entrega, actualizaciones..)',
    'Reject Task' => 'Rechazar tarea',
    'Remind Mode' => 'Modo de recordatorio',
    'Reminder' => 'Recordatorio',
    'Reminder sent' => 'Recordatorio enviado',
    'Reminders' => 'Recordatorios',
    'Request extension' => 'Solicitar extensión de plazo',
    'Request sent' => 'Solicitud enviada',
    'Reset Task' => 'Reiniciar tarea',
    'Responsible' => 'Responsable',
    'Responsible users' => 'Usuarios responsables',
    'Review by responsible user required' => 'Se requiere la revisión por los usuarios responsables',
    'Scheduling' => 'Agendado',
    'Show widget in Spaces' => 'Mostrar el widget en Espacios',
    'Show widget on Dashboard' => 'Mostrar el widget en el tablero',
    'Show {count} more completed {countTasks,plural,=1{task} other{tasks}}' => 'Mostrar {count} más completada {countTasks,plural,=1{task} other{tasks}}',
    'Sort Order' => 'Orden de clasificación',
    'Sort order' => 'Ordenado por',
    'Spaces' => 'Espacios',
    'Start' => 'Empezar',
    'Start Date' => 'Fecha de inicio',
    'Start Time' => 'Hora de Inicio',
    'Start date' => 'Fecha de inicio',
    'Starting at' => 'Comienza:',
    'Status' => 'Estado',
    'Task' => 'Tarea',
    'Task List' => 'Lista de tareas',
    'Task Users have been notified' => 'Usuarios de tareas han sido notificado',
    'Task {task} in space {spaceName} ends at {dateTime}.' => 'Tarea {task} en espacio {spaceName} termina: {dateTime}.',
    'Task {task} in space {spaceName} starts at {dateTime}.' => 'Tarea {task} en espacio {spaceName} comienza: {dateTime}.',
    'Tasks' => 'Tareas',
    'Tasks: Reminder' => 'Tareas: Recordatorio',
    'This task requires to be reviewed by a responsible' => 'Esta tarea requiere ser revisada por un responsable',
    'Time Zone' => 'Zona horaria',
    'Title' => 'Título',
    'Title and Color' => 'Título y Color',
    'Title of your task list' => 'Título de tu lista de tareas',
    'Today' => 'Hoy',
    'Unsorted' => 'Sin ordenar',
    'View Online' => 'Ver en línea',
    'You have insufficient permissions to perform that operation!' => '¡No tienes suficientes permisos para hacer esa operación!',
    'Your Reminder for task {task}' => 'Tu recordatorio para la tarea {task}',
    'view all' => 'ver todo',
    '{count,plural,=1{# day} other{# days}} remaining' => '{count,plural,=1{Queda # día} other{Quedan # días}}',
    '{displayName} is assigned to this task' => '{displayName} ha sido asignado para esta tarea',
    '{displayName} is responsible for this task' => '{displayName} es responsable de esta tarea',
    '{userName} assigned you as responsible person in task {task} from space {spaceName}.' => '{userName} te ha asignado como <strong>persona responsable</strong> a cargo de la tarea {task} desde el espacio {spaceName}',
    '{userName} assigned you to task {task} in space {spaceName}.' => '{userName} te ha asignado la tarea {task} en el espacio {spaceName}.',
    '{userName} completed Task {task} in space {spaceName}.' => '{userName} completó la tarea: {task} en el espacio {spaceName}.',
    '{userName} completed task {task}.' => '{userName} completó la tarea {task}.',
    '{userName} finished task {task}.' => '{userName} completó la tarea {task}.',
    '{userName} has changed deadline for task {task} in space {spaceName}.' => '{userName} ha cambiado la fecha límite de la tarea {task} en el espacio {spaceName}.',
    '{userName} has re-opened task {task} in space {spaceName}.' => '{userName} ha re-abierto la tarea {task} en el espacio {spaceName}.',
    '{userName} has rejected task {task} in space {spaceName} as incomplete.' => '{userName} ha calificado la tarea {task} en el espacio {spaceName} como incompleta.',
    '{userName} marked Task {task} in space {spaceName} as completed.' => '{userName} marcó la tarea {task} en el espacio {spaceName} como completada.',
    '{userName} requests a deadline extension for task {task} in space {spaceName}.' => '{userName} ha solicitado una extensión de la fecha de entrega para la tarea {task} en el espacio {spaceName}.',
    '{userName} requests you to review Task {task} in space {spaceName}.' => '{userName} te ha solicitado revisar la tarea: {task} en el espacio {spaceName}.',
    '{userName} reset task {task}.' => '{userName} restauró la tarea {task}.',
    '{userName} reviewed task {task}.' => '{userName} revisó la tarea {task}.',
    '{userName} started working on Task {task} in space {spaceName}.' => '{userName} ha empezado a trabajar en la tarea: {task} en el espacio {spaceName}.',
    '{userName} works on task {task}.' => '{userName} está trabajando en la tarea {task}.',
    'Assignments' => '',
    'Deadline' => '',
    'ID' => '',
    'Request Review' => '',
    'Task content ID' => '',
    '{displayName} is task creator' => '',
];
